/* ******************************************************************************

	FILE:			SSMinimalApp.h
	AUTHOR:			Jean-Sbastien Perrier

	DESCRIPTION:	Minimal screen saver implementation example.
					It shows a texture spinning cube with a flashing
					background.

	$History::                                                                  $

****************************************************************************** */
#ifdef _MSC_VER
	#pragma once
#endif
#ifndef SSMINIMALAPP_H
#define SSMINIMALAPP_H

// Includes ****************************************************************** //
#include "SSBaseApp.h"
#include "SSTexture.h"

// Defines ******************************************************************* //

// Forward definitions ******************************************************* //

// Types ********************************************************************* //

////////////////////////////////////////////////////////////////////////////////
// CLASS:			SSMinimalApp
// INHERITS FROM:	SSBaseApp
// DESCRIPTION:		Minimal screen saver.
// REMARKS:			None
////////////////////////////////////////////////////////////////////////////////
class SSMinimalApp : public SSBaseApp
{
private:
	BOOL m_bRotate;				// Rotation flag.
	BOOL m_bFlash;				// Flash flag.
	char m_szTextureFile[256];	// Texture file name
	
	// -- Internal stuff --
	float m_fLastTime;			// Time for the last frame.
	// Parameters for the rotation effect
	float m_afRot[3];			// X Y Z rotation angles in degrees.
	float m_afRotSpeed[3];		// X Y Z rotation speed in degrees/sec.
	// Parameters for the flashing effect
	float m_afFlashColor[3];	// RGB Color for the flash effect.
	float m_fNextFlash;			// Time for the next flash.
	float m_fFlashPeriod;		// Time between each flash.
	bool m_bFlashed;			// true if the flash occured.


	SSTexture *m_pTexture;		// Texture for this example.

public:
	SSMinimalApp(HINSTANCE a_hInstance);
	virtual ~SSMinimalApp() {}

	virtual void ReadConfigRegistry();
	virtual void WriteConfigRegistry();
	virtual bool InitGL(int w, int h);
	virtual void ReleaseGL();
	virtual void Update();
	virtual void Display();

	// Get methods
	BOOL GetRotate() const {return m_bRotate;}
	BOOL GetFlash() const {return m_bFlash;}
	char *GetTextureFile() {return m_szTextureFile;}
	// Set methods
	void SetRotate(BOOL val) {m_bRotate = val;}
	void SetFlash(BOOL val) {m_bFlash = val;}
	void SetTextureFile(const char *a_szName);
};

// Consts ******************************************************************** //

// Globals ******************************************************************* //

// Function Prototypes ******************************************************* //

// Inline Functions ********************************************************** //

#endif // SSMINIMALAPP_H
